@@ -27,7 +27,6 @@
 #include <spice-client-gtk-3.0/spice-widget.h>
 #include <gdk/gdkkeysyms.h>
 
-#include <vinagre/vinagre-utils.h>
 #include <vinagre/vinagre-prefs.h>
 
 #include "vinagre-spice-tab.h"
@@ -249,7 +248,7 @@ open_spice (VinagreSpiceTab *spice_tab)
 	if (!vinagre_spice_tunnel_create (window, &host, &port_str, ssh_tunnel_host, &error))
 	  {
 	    success = FALSE;
-	    vinagre_utils_show_error (_("Error creating the SSH tunnel"),
+	    vinagre_utils_show_error_dialog (_("Error creating the SSH tunnel"),
 				      error ? error->message : _("Unknown reason"),
 				      window);
 	    goto out;
@@ -261,7 +260,7 @@ open_spice (VinagreSpiceTab *spice_tab)
     }
 
   if (!success)
-    vinagre_utils_show_error (_("Error connecting to host."),
+    vinagre_utils_show_error_dialog (_("Error connecting to host."),
 			      error ? error->message : _("Unknown reason"),
 			      window);
 
@@ -294,7 +293,7 @@ spice_main_channel_event_cb(SpiceChannel *channel, SpiceChannelEvent event,
     gboolean save_in_keyring = FALSE;
 
     vinagre_tab_remove_credentials_from_keyring (VINAGRE_TAB (tab));
-    if (!vinagre_utils_ask_credential (window,
+    if (!vinagre_utils_request_credential (window,
 				       "SPICE",
 				       name,
 				       FALSE,
@@ -521,15 +520,15 @@ create_initialized_actions (VinagreSpiceTab *tab)
   GSList *list = NULL;
   VinagreTabUiAction *a;
 
-  /* Machine->Send CTRL-ALT-DEL */
+  /* Remote->Send CTRL-ALT-DEL */
   a = g_new (VinagreTabUiAction, 1);
   a->paths = g_new (gchar *, 3);
-  a->paths[0] = g_strdup ("/MenuBar/MachineMenu/MachineOps_1");
+  a->paths[0] = g_strdup ("/MenuBar/RemoteeMenu/RemoteOps_1");
   a->paths[1] = g_strdup ("/ToolBar");
   a->paths[2] = NULL;
-  a->action = gtk_action_new ("SPICEMachineSendCtrlAltDel",
+  a->action = gtk_action_new ("SPICERemoteSendCtrlAltDel",
 			      _("_Send Ctrl-Alt-Del"),
-			      _("Sends Ctrl+Alt+Del to the remote machine"),
+			      _("Sends Ctrl+Alt+Del to the remote desktop"),
 			      "preferences-desktop-keyboard-shortcuts");
   gtk_action_set_is_important (a->action, TRUE);
   gtk_action_set_icon_name (a->action, "preferences-desktop-keyboard-shortcuts");
