@@ -28,19 +28,24 @@
 #include <string.h>
 
 #include "vinagre-commands.h"
-#include "vinagre-utils.h"
 #include "vinagre-connection.h"
 #include "vinagre-notebook.h"
 #include "vinagre-tab.h"
 #include "vinagre-connect.h"
 #include "vinagre-bookmarks.h"
 #include "vinagre-bookmarks-ui.h"
-#include "vinagre-fav.h"
 #include "vinagre-window-private.h"
 #include "vinagre-prefs.h"
 #include "vinagre-cache-prefs.h"
 #include "vinagre-plugins-engine.h"
-#include "vinagre-plugin-dialog.h"
+
+static void _toggle_widget_visible (GtkWidget *widget)
+{
+    if (gtk_widget_get_visible (widget))
+        gtk_widget_hide (widget);
+    else
+        gtk_widget_show_all (widget);
+}
 
 void
 vinagre_cmd_direct_connect (VinagreConnection *conn,
@@ -64,9 +69,9 @@ vinagre_cmd_direct_connect (VinagreConnection *conn,
     }
 }
 
-/* Machine Menu */
+/* Remote Menu */
 void
-vinagre_cmd_machine_connect (GtkAction     *action,
+vinagre_cmd_remote_connect (GtkAction     *action,
 			     VinagreWindow *window)
 {
   VinagreTab *tab;
@@ -101,7 +106,7 @@ vinagre_cmd_free_string_list (gpointer str, gpointer user_data)
 }
 
 void
-vinagre_cmd_machine_open (GtkAction     *action,
+vinagre_cmd_remote_open (GtkAction     *action,
 			  VinagreWindow *window)
 {
   GtkWidget         *tab;
@@ -143,7 +148,7 @@ vinagre_cmd_machine_open (GtkAction     *action,
 
   if (i == 0)
     {
-      vinagre_utils_show_error (_("There are no supported files"),
+      vinagre_utils_show_error_dialog (_("There are no supported files"),
 				_("None of the active plugins support this action. Activate some plugins and try again."),
 				GTK_WINDOW (window));
       goto finalize;
@@ -192,28 +197,35 @@ finalize:
 }
 
 void
-vinagre_cmd_machine_close (GtkAction     *action,
+vinagre_cmd_remote_disconnect (GtkAction     *action,
 			   VinagreWindow *window)
 {
   vinagre_window_close_active_tab (window);
 }
 
 void
-vinagre_cmd_machine_take_screenshot (GtkAction     *action,
+vinagre_cmd_remote_take_screenshot (GtkAction     *action,
 				     VinagreWindow *window)
 {
   vinagre_tab_take_screenshot (vinagre_window_get_active_tab (window));
 }
 
 void
-vinagre_cmd_machine_close_all (GtkAction     *action,
+vinagre_cmd_remote_disconnect_all (GtkAction     *action,
 			       VinagreWindow *window)
 {
   vinagre_window_close_all_tabs (window);
 }
 
 void
-vinagre_cmd_machine_quit (GtkAction     *action,
+vinagre_cmd_remote_vnc_listener (GtkAction *action,
+                                 VinagreWindow *window)
+{
+    vinagre_reverse_vnc_listener_dialog_show (window);
+}
+
+void
+vinagre_cmd_remote_quit (GtkAction     *action,
 			  VinagreWindow *window)
 {
   gtk_widget_destroy (GTK_WIDGET (window));
@@ -233,7 +245,7 @@ vinagre_cmd_edit_plugins (GtkAction     *action,
 {
   g_return_if_fail (VINAGRE_IS_WINDOW (window));
 
-  vinagre_plugin_dialog_show (GTK_WINDOW (window));
+  g_warn_if_reached ();
 }
 
 /* View Menu */
@@ -243,7 +255,7 @@ vinagre_cmd_view_show_toolbar	(GtkAction     *action,
 {
   g_return_if_fail (VINAGRE_IS_WINDOW (window));
 
-  vinagre_utils_toggle_widget_visible (window->priv->toolbar);
+  _toggle_widget_visible (window->priv->toolbar);
 
   vinagre_cache_prefs_set_boolean ("window",
 				   "toolbar-visible",
@@ -256,26 +268,13 @@ vinagre_cmd_view_show_statusbar	(GtkAction     *action,
 {
   g_return_if_fail (VINAGRE_IS_WINDOW (window));
 
-  vinagre_utils_toggle_widget_visible (window->priv->statusbar);
+  _toggle_widget_visible (window->priv->statusbar);
 
   vinagre_cache_prefs_set_boolean ("window",
 				   "statusbar-visible",
 				   gtk_widget_get_visible (window->priv->statusbar));
 }
 
-void
-vinagre_cmd_view_show_fav_panel	(GtkAction     *action,
-				 VinagreWindow *window)
-{
-  g_return_if_fail (VINAGRE_IS_WINDOW (window));
-
-  vinagre_utils_toggle_widget_visible (window->priv->fav_panel);
-
-  vinagre_cache_prefs_set_boolean ("window",
-				   "side-panel-visible",
-				   gtk_widget_get_visible (window->priv->fav_panel));
-}
-
 void
 vinagre_cmd_view_fullscreen (GtkAction     *action,
 			     VinagreWindow *window)
@@ -342,14 +341,14 @@ void
 vinagre_cmd_help_contents (GtkAction     *action,
 			   VinagreWindow *window)
 {
-  vinagre_utils_help_contents (GTK_WINDOW (window), NULL);
+  vinagre_utils_show_help (GTK_WINDOW (window), NULL);
 }
 
 void
 vinagre_cmd_help_about (GtkAction     *action,
 			VinagreWindow *window)
 {
-  vinagre_utils_help_about (GTK_WINDOW (window));
+  vinagre_utils_show_help_about (GTK_WINDOW (window));
 }
 
 /* vim: set ts=8: */
