@@ -30,7 +30,6 @@
 #include <gnome-keyring.h>
 
 #include "vinagre-ssh.h"
-#include "vinagre-utils.h"
 #include "pty_open.h"
 
 #define SSH_READ_TIMEOUT 40   /* seconds */
@@ -294,6 +293,60 @@ get_hostname_and_fingerprint_from_line (const gchar *buffer,
   return TRUE;
 }
 
+/**
+ * _ask_question:
+ * @parent: transient parent, or NULL for none
+ * @message: The message to be displayed, if it contains multiple lines,
+ *  the first one is considered as the title.
+ * @choices: NULL-terminated array of button's labels of the dialog
+ * @choice: Place to store the selected button. Zero is the first.
+ *
+ * Displays a dialog with a message and some options to the user.
+ *
+ * Returns TRUE if the user has selected any option, FALSE if the dialog
+ *  was canceled.
+ */
+static gboolean
+_ask_question (GtkWindow  *parent,
+			    const char *message,
+			    char       **choices,
+			    int        *choice)
+{
+  gchar **messages;
+  GtkWidget *d;
+  int i, n_choices, result;
+
+  g_return_val_if_fail (message && choices && choice, FALSE);
+
+  messages = g_strsplit (message, "\n", 2);
+
+  d = gtk_message_dialog_new (parent,
+			      GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+			      GTK_MESSAGE_QUESTION,
+			      GTK_BUTTONS_NONE,
+			      "%s",
+			      messages[0]);
+
+  if (g_strv_length (messages) > 1)
+    gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (d),
+						"%s",
+						messages[1]);
+  g_strfreev (messages);
+
+  n_choices = g_strv_length (choices);
+  for (i = 0; i < n_choices; i++)
+    gtk_dialog_add_button (GTK_DIALOG (d), choices[i], i);
+
+  result = gtk_dialog_run (GTK_DIALOG (d));
+  gtk_widget_destroy (d);
+
+  if (result == GTK_RESPONSE_NONE || result == GTK_RESPONSE_DELETE_EVENT)
+    return FALSE;
+
+  *choice = result;
+  return TRUE;
+}
+
 static gboolean
 handle_login (GtkWindow *parent,
 	      const   gchar *host,
@@ -312,7 +365,7 @@ handle_login (GtkWindow *parent,
   int prompt_fd;
   char buffer[1024];
   gsize len;
-  gboolean ret_val, aborted, save_in_keyring;
+  gboolean ret_val, save_in_keyring;
   gsize bytes_written;
   const gchar *authtype;
   gchar *object, *password;
@@ -323,7 +376,7 @@ handle_login (GtkWindow *parent,
   object = password = NULL;
   authtype = NULL;
   ret_val = TRUE;
-  aborted = save_in_keyring = FALSE;
+  save_in_keyring = FALSE;
 
   if (vendor == SSH_VENDOR_SSH) 
     prompt_fd = stderr_fd;
@@ -364,6 +417,13 @@ handle_login (GtkWindow *parent,
               ret_val = FALSE;
               break;
             }
+
+          if (len == 0) /* Error, let's exit and look at stderr */
+            {
+              ret_val = TRUE;
+              break;
+            }
+
           buffer[len] = 0;
           if (strncmp (buffer, VINAGRE_SSH_CHECK, VINAGRE_SSH_CHECK_LENGTH) == 0)
             break;
@@ -423,14 +483,8 @@ handle_login (GtkWindow *parent,
 	      gboolean res;
 
 	      full_host = g_strjoin ("@", user, host, NULL);
-	      res = vinagre_utils_ask_credential (parent,
-						  "SSH",
-						  full_host,
-						  FALSE,
-						  TRUE,
-						  NULL,
-						  &password,
-						  &save_in_keyring);
+	      res = vinagre_utils_request_credential (parent, "SSH", full_host,
+		  FALSE, TRUE, 0, NULL, &password, &save_in_keyring);
 	      g_free (full_host);
               if (!res)
                 {
@@ -477,9 +531,9 @@ handle_login (GtkWindow *parent,
 
 	  get_hostname_and_fingerprint_from_line (buffer, &hostname, &fingerprint);
 
-	  message = g_strdup_printf (_("The identity of the remote computer (%s) is unknown.\n"
-				       "This happens when you log in to a computer the first time.\n\n"
-				       "The identity sent by the remote computer is %s. "
+	  message = g_strdup_printf (_("The identity of the remote host (%s) is unknown.\n"
+				       "This happens when you log in to a host the first time.\n\n"
+				       "The identity sent by the remote host is %s. "
 				       "If you want to be absolutely sure it is safe to continue, "
 				       "contact the system administrator."),
 				     hostname ? hostname : host, fingerprint);
@@ -487,7 +541,7 @@ handle_login (GtkWindow *parent,
 	  g_free (hostname);
 	  g_free (fingerprint);
 
-	  if (!vinagre_utils_ask_question (NULL,
+	  if (!_ask_question (NULL,
 					   message,
 					   (char **)choices,
 					   &choice))
@@ -551,7 +605,7 @@ handle_login (GtkWindow *parent,
                 &keyring_item_id);
 
       if (result != GNOME_KEYRING_RESULT_OK)
-        vinagre_utils_show_error (_("Error saving the credentials on the keyring."),
+        vinagre_utils_show_error_dialog (_("Error saving the credentials on the keyring."),
 				  gnome_keyring_result_to_message (result),
 				  parent);
 
@@ -561,6 +615,7 @@ handle_login (GtkWindow *parent,
   g_object_unref (prompt_stream);
   g_object_unref (stdout_stream);
   g_object_unref (reply_stream);
+
   return ret_val;
 }
 
