@@ -28,7 +28,6 @@
 
 #include "vinagre-tab.h"
 #include "vinagre-notebook.h"
-#include "vinagre-utils.h"
 #include "vinagre-prefs.h"
 #include "view/autoDrawer.h"
 #include "vinagre-plugins-engine.h"
@@ -351,7 +350,7 @@ setup_layout (VinagreTab *tab)
 
   /* Close connection */
   button = GTK_WIDGET (gtk_tool_button_new_from_stock (GTK_STOCK_CLOSE));
-  gtk_tool_item_set_tooltip_text (GTK_TOOL_ITEM (button), _("Close connection"));
+  gtk_tool_item_set_tooltip_text (GTK_TOOL_ITEM (button), _("Disconnect"));
   gtk_widget_show (GTK_WIDGET (button));
   gtk_toolbar_insert (GTK_TOOLBAR (tab->priv->toolbar), GTK_TOOL_ITEM (button), 0);
   g_signal_connect (button, "clicked", G_CALLBACK (close_button_clicked), tab);
@@ -533,7 +532,7 @@ vinagre_tab_add_recent_used (VinagreTab *tab)
   data->is_private = FALSE;
 
   if (!gtk_recent_manager_add_full (manager, uri, data))
-    vinagre_utils_show_error (NULL,
+    vinagre_utils_show_error_dialog (NULL,
 			      _("Error saving recent connection."),
 			      GTK_WINDOW (tab->priv->window));
 
@@ -803,7 +802,7 @@ vinagre_tab_save_credentials_in_keyring (VinagreTab *tab)
                 &tab->priv->keyring_item_id);
 
   if (result != GNOME_KEYRING_RESULT_OK)
-    vinagre_utils_show_error (_("Error saving the credentials on the keyring."),
+    vinagre_utils_show_error_dialog (_("Error saving the credentials on the keyring."),
 			      gnome_keyring_result_to_message (result),
 			      GTK_WINDOW (tab->priv->window));
 
@@ -891,7 +890,7 @@ vinagre_tab_take_screenshot (VinagreTab *tab)
   pix = VINAGRE_TAB_GET_CLASS (tab)->impl_get_screenshot (tab);
   if (!pix)
     {
-      vinagre_utils_show_error (NULL,
+      vinagre_utils_show_error_dialog (NULL,
 				_("Could not get a screenshot of the connection."),
 				GTK_WINDOW (tab->priv->window));
       return;
@@ -960,7 +959,7 @@ vinagre_tab_take_screenshot (VinagreTab *tab)
 
       if (!gdk_pixbuf_save (pix, filename, name, &error, NULL))
 	{
-	  vinagre_utils_show_error (_("Error saving screenshot"),
+	  vinagre_utils_show_error_dialog (_("Error saving screenshot"),
 				    error->message,
 				    GTK_WINDOW (tab->priv->window));
 	  g_error_free (error);
