@@ -34,10 +34,8 @@
 
 #include "vinagre-window.h"
 #include "vinagre-notebook.h"
-#include "vinagre-fav.h"
 #include "vinagre-prefs.h"
 #include "vinagre-cache-prefs.h"
-#include "vinagre-util.h"
 #include "vinagre-bookmarks.h"
 #include "vinagre-ui.h"
 #include "vinagre-window-private.h"
@@ -70,19 +68,6 @@ vinagre_window_dispose (GObject *object)
 {
   VinagreWindow *window = VINAGRE_WINDOW (object);
 
-  peas_engine_garbage_collect (PEAS_ENGINE (vinagre_plugins_engine_get_default ()));
-
-  if (!window->priv->dispose_has_run)
-    {
-      peas_extension_set_call (window->priv->extensions,
-			       "deactivate",
-			       window);
-
-      g_object_unref (window->priv->extensions);
-      peas_engine_garbage_collect (PEAS_ENGINE (vinagre_plugins_engine_get_default ()));
-      window->priv->dispose_has_run = TRUE;
-    }
-
   if (window->priv->manager)
     {
       g_object_unref (window->priv->manager);
@@ -98,8 +83,11 @@ vinagre_window_dispose (GObject *object)
       window->priv->update_recents_menu_ui_id = 0;
     }
 
-  peas_engine_garbage_collect (PEAS_ENGINE (vinagre_plugins_engine_get_default ()));
-
+    if (window->priv->listener)
+    {
+        g_object_unref (window->priv->listener);
+        window->priv->listener = NULL;
+    }
   G_OBJECT_CLASS (vinagre_window_parent_class)->dispose (object);
 }
 
@@ -122,9 +110,6 @@ vinagre_window_show_hide_controls (VinagreWindow *window)
 {
   if (window->priv->fullscreen)
     {
-      window->priv->fav_panel_visible = gtk_widget_get_visible (window->priv->fav_panel);
-      gtk_widget_hide (window->priv->fav_panel);
-
       window->priv->toolbar_visible = gtk_widget_get_visible (window->priv->toolbar);
       gtk_widget_hide (window->priv->toolbar);
 
@@ -138,9 +123,6 @@ vinagre_window_show_hide_controls (VinagreWindow *window)
     }
   else
     {
-      if (window->priv->fav_panel_visible)
-        gtk_widget_show_all (window->priv->fav_panel);
-
       if (window->priv->toolbar_visible)
         gtk_widget_show_all (window->priv->toolbar);
 
@@ -482,14 +464,46 @@ create_menu_bar_and_toolbar (VinagreWindow *window,
   show_hide_accels (window);
 }
 
-static void
-fav_panel_size_allocate (GtkWidget     *widget,
-			 GtkAllocation *allocation,
-			 VinagreWindow *window)
+/*
+ * Doubles underscore to avoid spurious menu accels.
+ */
+static gchar *
+_escape_underscores (const gchar* text,
+	gssize       length)
 {
-  window->priv->side_panel_size = allocation->width;
-  if (window->priv->side_panel_size > 0)
-    vinagre_cache_prefs_set_integer ("window", "side-panel-size", window->priv->side_panel_size);
+	GString *str;
+	const gchar *p;
+	const gchar *end;
+
+	g_return_val_if_fail (text != NULL, NULL);
+
+	if (length < 0)
+		length = strlen (text);
+
+	str = g_string_sized_new (length);
+
+	p = text;
+	end = text + length;
+
+	while (p != end)
+	{
+		const gchar *next;
+		next = g_utf8_next_char (p);
+
+		switch (*p)
+		{
+			case '_':
+				g_string_append (str, "__");
+				break;
+			default:
+				g_string_append_len (str, p, next - p);
+				break;
+		}
+
+		p = next;
+	}
+
+	return g_string_free (str, FALSE);
 }
 
 static void
@@ -513,7 +527,7 @@ vinagre_window_populate_bookmarks (VinagreWindow *window,
       switch (vinagre_bookmarks_entry_get_node (entry))
 	{
 	  case VINAGRE_BOOKMARKS_ENTRY_NODE_FOLDER:
-	    action_label = vinagre_utils_escape_underscores (vinagre_bookmarks_entry_get_name (entry), -1);
+	    action_label = _escape_underscores (vinagre_bookmarks_entry_get_name (entry), -1);
 	    action_name = g_strdup_printf ("BOOKMARK_FOLDER_ACTION_%d", ++i);
 	    action = gtk_action_new (action_name,
 				     action_label,
@@ -549,7 +563,7 @@ vinagre_window_populate_bookmarks (VinagreWindow *window,
 	     continue;
 
 	    action_name = vinagre_connection_get_best_name (conn);
-	    action_label = vinagre_utils_escape_underscores (action_name, -1);
+	    action_label = _escape_underscores (action_name, -1);
 	    g_free (action_name);
 
 	    action_name = g_strdup_printf ("BOOKMARK_ITEM_ACTION_%d", ++i);
@@ -569,10 +583,6 @@ vinagre_window_populate_bookmarks (VinagreWindow *window,
 	    g_object_set_data (G_OBJECT (action), "conn", conn);
 	    gtk_action_group_add_action (p->bookmarks_list_action_group,
 					 action);
-	    g_signal_connect (action,
-			     "activate",
-			     G_CALLBACK (vinagre_fav_bookmarks_open),
-			     window->priv->fav_panel);
 
 	    path = g_strdup_printf ("/MenuBar/BookmarksMenu/%s%s", group, parent?parent:"");
 	    gtk_ui_manager_add_ui (p->manager,
@@ -610,9 +620,6 @@ vinagre_window_update_bookmarks_list_menu (VinagreWindow *window)
   actions = gtk_action_group_list_actions (p->bookmarks_list_action_group);
   for (l = actions; l != NULL; l = l->next)
     {
-      g_signal_handlers_disconnect_by_func (GTK_ACTION (l->data),
-					    G_CALLBACK (vinagre_fav_bookmarks_open),
-					    window->priv->fav_panel);
       gtk_action_group_remove_action (p->bookmarks_list_action_group,
 				      GTK_ACTION (l->data));
     }
@@ -629,38 +636,12 @@ vinagre_window_update_bookmarks_list_menu (VinagreWindow *window)
   vinagre_window_populate_bookmarks (window, "AvahiList", mdnss, NULL);
 }
 
-static void
-create_side_panel (VinagreWindow *window)
-{
-  window->priv->fav_panel = vinagre_fav_new (window);
-
-  gtk_paned_pack1 (GTK_PANED (window->priv->hpaned), 
-		   window->priv->fav_panel, 
-		   FALSE, 
-		   FALSE);
-
-  window->priv->side_panel_size = vinagre_cache_prefs_get_integer ("window", "side-panel-size", 200);
-  gtk_paned_set_position (GTK_PANED (window->priv->hpaned), window->priv->side_panel_size);
-
-  g_signal_connect (window->priv->fav_panel,
-		    "size-allocate",
-		    G_CALLBACK (fav_panel_size_allocate),
-		    window);
-}
-
 static void
 init_widgets_visibility (VinagreWindow *window)
 {
   GtkAction *action;
   gboolean visible;
 
-  /* side panel visibility */
-  action = gtk_action_group_get_action (window->priv->always_sensitive_action_group,
-					"ViewSidePanel");
-  visible = vinagre_cache_prefs_get_boolean ("window", "side-panel-visible", TRUE);
-  if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)) != visible)
-    gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), visible);
-
   /* toolbar visibility */
   action = gtk_action_group_get_action (window->priv->always_sensitive_action_group,
 					"ViewToolbar");
@@ -704,16 +685,30 @@ create_statusbar (VinagreWindow *window,
 }
 
 static void
-create_notebook (VinagreWindow *window)
+_create_notebook (VinagreWindow *window, GtkWidget *main_box)
 {
-  window->priv->notebook = vinagre_notebook_new (window);
+    window->priv->notebook = vinagre_notebook_new (window);
 
-  gtk_paned_pack2 (GTK_PANED (window->priv->hpaned), 
-  		   GTK_WIDGET (window->priv->notebook),
-  		   TRUE, 
-  		   FALSE);
+    gtk_box_pack_start (GTK_BOX (main_box), GTK_WIDGET (window->priv->notebook),
+        TRUE, FALSE, 0);
 
-  gtk_widget_show (GTK_WIDGET (window->priv->notebook));
+    gtk_widget_show (GTK_WIDGET (window->priv->notebook));
+}
+
+/* Initialise the reverse connections dialog, and start the listener if it is
+ * enabled. */
+static void
+_init_reverse_connections (VinagreWindow *window)
+{
+    gboolean always;
+    VinagreReverseVncListener *listener = window->priv->listener;
+
+    listener = vinagre_reverse_vnc_listener_get_default ();
+
+    g_object_get (vinagre_prefs_get_default (), "always-enable-listening",
+        &always, NULL);
+    if (always)
+        vinagre_reverse_vnc_listener_start (listener);
 }
 
 static gboolean
@@ -759,24 +754,6 @@ vinagre_window_check_first_run (VinagreWindow *window)
   return FALSE;
 }
 
-static void
-extension_added (PeasExtensionSet *extensions,
-		 PeasPluginInfo   *info,
-		 PeasExtension    *exten,
-		 gpointer          user_data)
-{
-  peas_extension_call (exten, "activate");
-}
-
-static void
-extension_removed (PeasExtensionSet *extensions,
-		   PeasPluginInfo   *info,
-		   PeasExtension    *exten,
-		   gpointer          user_data)
-{
-  peas_extension_call (exten, "deactivate");
-}
-
 static void
 protocol_added_removed_cb (VinagrePluginsEngine *engine,
 			   VinagreProtocol      *protocol,
@@ -807,21 +784,8 @@ vinagre_window_init (VinagreWindow *window)
   /* Add status bar */
   create_statusbar (window, main_box);
 
-  /* Add the main area */
-  window->priv->hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
-  gtk_box_pack_start (GTK_BOX (main_box), 
-  		      window->priv->hpaned, 
-  		      TRUE, 
-  		      TRUE, 
-  		      0);
-
   /* setup notebook area */
-  create_notebook (window);
-
-  /* side panel */
-  create_side_panel (window);
-
-  gtk_widget_show (window->priv->hpaned);
+  _create_notebook (window, main_box);
 
   init_widgets_visibility (window);
 //  vinagre_window_merge_tab_ui (window);
@@ -839,19 +803,6 @@ vinagre_window_init (VinagreWindow *window)
 #endif
 
   engine = vinagre_plugins_engine_get_default ();
-  window->priv->extensions = peas_extension_set_new (PEAS_ENGINE (engine),
-						     PEAS_TYPE_ACTIVATABLE,
-						     "object", window,
-						     NULL);
-  g_signal_connect (window->priv->extensions,
-		    "extension-added",
-		    G_CALLBACK (extension_added),
-		    window);
-  g_signal_connect (window->priv->extensions,
-		    "extension-removed",
-		    G_CALLBACK (extension_removed),
-		    window);
-  peas_extension_set_call (window->priv->extensions, "activate");
 
   g_signal_connect_after (engine,
 			  "protocol-added",
@@ -862,6 +813,7 @@ vinagre_window_init (VinagreWindow *window)
 			  G_CALLBACK (protocol_added_removed_cb),
 			  window);
 
+  _init_reverse_connections (window);
   g_idle_add ((GSourceFunc) vinagre_window_check_first_run, window);
 }
 
@@ -1012,20 +964,6 @@ vinagre_window_get_connected_action (VinagreWindow *window)
   return window->priv->remote_connected_action_group;
 }
 
-/**
- * vinagre_window_get_fav_panel:
- * @window: A window
- *
- * Return value: (transfer none):
- */
-GtkWidget *
-vinagre_window_get_fav_panel (VinagreWindow *window)
-{
-  g_return_val_if_fail (VINAGRE_IS_WINDOW (window), NULL);
-
-  return window->priv->fav_panel;
-}
-
 void
 vinagre_window_close_active_tab	(VinagreWindow *window)
 {
@@ -1139,5 +1077,3 @@ vinagre_window_conn_exists (VinagreWindow *window, VinagreConnection *conn)
 
   return tab;
 }
-
-/* vim: set ts=8: */
